# Video_player: ビデオプレイヤー

`video_player (ビデオプレイヤー)` では動画を再生することができます。このプラグインは基本的なビデオ再生用で、バックエンドとして`legacy`を選択する必要があります。より高度なビデオ再生機能には、`media_player_vlc` プラグインをおすすめします。

以下のオプションが利用できます:

- *Video file (ビデオファイル)*: ファイルプールに存在する動画ファイル利用するプラットフォームが読み込む動画のフォーマットをサポートしている必要があります。一般的に使用されている拡張子(例として `.avi` や `.mpeg`)は多くの場合対応しています。
- *Resize to fit screen (画面に合わせる)*: 画面全体に合うようにビデオのサイズを変更する必要があるかどうかを設定できます。指定しない場合、ビデオはディスプレイの中央に表示されます。
- *Duration (呈示時間)*: ms単位の再生時間、'keypress' (キー入力で再生を停止) もしくは 'mouseclick' (マウスによるクリックで再生を停止) を選択することができます。
- *Frame duration (フレーム間隔)*: 1つのフレームの継続時間(ミms秒単位)。これにより再生速度を制御することができます。最大再生速度は、コンピュータの速度によって異なります。


